# aws-requests-auth-stubs
<a href="https://github.com/YonatanGreenfeld/aws-requests-auth-stubs/blob/main/LICENSE"><img alt="License: MIT" src="https://black.readthedocs.io/en/stable/_static/license.svg"></a>
<a href="http://mypy-lang.org/"><img alt="Checked with mypy" src="http://www.mypy-lang.org/static/mypy_badge.svg"></a>
<a href="https://github.com/psf/black"><img alt="Code style: black" src="https://img.shields.io/badge/code%20style-black-000000.svg"></a>

PEP-561 stub package for the [aws-requests-auth](https://github.com/DavidMuller/aws-requests-auth) package.
